package remoteLaunch;
import java.util.*;
import java.net.*;
import java.io.*;
/**
* The class ProgramLoader load remote class.
* @author Pellier Damien 
* @version	1.0 date : 15/07/2001
* <dt><b>key-word</b><code>
* <dd>	RMI
* </code>
* @see <a href="ProgramLoader.java">ProgramLoader</a>
*/
public class ProgramLoader extends ClassLoader {
	/**
	* The base directory for loading local classes
	*/
	private String basedir;
	/**
	* Indicate if the first argument is a file or a url
	*/
	private boolean url;
	/**
	* The cache for name binding
	*/
	Hashtable cache = new Hashtable();
	/**
	* Constructor of class ProgramLoader
	* @param dir the path where find classes
	*/
	public ProgramLoader(String dir) {
		this.basedir = dir;
		if (dir.startsWith("http")) url = true;
		else url = false;			
	}
	/**
	* The main entry point of the class which allows class names to be bound and classes to be loaded if needed.
	* @param name the name of the class to find
	*/
	public synchronized Class loadClass(String name) {
		Class  theclass;
		// First case: the name is already resolved in the cache.
		theclass = (Class)cache.get(name);
		if (theclass != null) return theclass;
		// Second case the class is a local class
		try {
			theclass = findSystemClass(name);
			cache.put(name,theclass);
			return theclass;
		} catch (ClassNotFoundException ex) {
			// Try to load it as a class from a file or web server
			byte data[];
			if (url) {
				data = loadClassDataFromURL(name);
			}
			else {
				data = loadClassDataFromFile(name);
			}
			if (data != null) {
				try {
					try {
						theclass = defineClass(name,data,0,data.length);
					} catch(Exception e) {
						System.out.println("loadClass: "+e);
						//e.printStackTrace();
					}
					cache.put(name,theclass);
					return theclass;
				} catch (ClassFormatError e1) {
					System.out.println("loadClass: "+e1);
					//e1.printStackTrace();
					return null;
				}
			}
		}
		return null;
	}
	/**
	* read an input strean until the end
	* @param ds the InputStream where read
	* @param zone a byte[] where put the result
	*/
	private int read(InputStream ds, byte zone[]) throws IOException {
		int n,off=0,len=zone.length;
		while (len>0) {
			n = ds.read(zone, off, len);
			if (n == -1) return off;
			len -= n; off +=n;
		}
		return len;
	}
	/**
	* read a class from a local file.
	* @param name the name of the class to read
	*/
	private byte loadClassDataFromFile (String name)[] {
		File class_file;
		FileInputStream class_stream;
		long len = 0;
		name = name.replace('.', '/');
		class_file = new File(basedir+"/"+name+".class");
		if (!class_file.exists()) return null;
		len = class_file.length();
		byte data[] = new byte[(int)len];
		try {
			class_stream = new FileInputStream(class_file);
			int x = read(class_stream, data);
			return data;
		} catch (FileNotFoundException e) {
			System.out.println("loadClassDataFromFile: "+e);
			return null;
		} catch (IOException e) {
			System.out.println("loadClassDataFromFile: "+e);
			return null;
		}
	}
	/**
	* read a class from a web server. Sorry, I can't do better if you look the source code !!! I can't get the size of the remote file before I read it ...
	* @param name the name of the class to read
	*/
	private byte loadClassDataFromURL (String name)[] {
		try {
			name = name.replace('.', '/');
			URL remloc = new URL(basedir+"/"+name+".class");
			DataInputStream dis = new DataInputStream(remloc.openStream());
			byte data[] = new byte[1000000];
			int x = read(dis, data);
			byte data2[] = new byte[x];
			for (int i = 0;i<x;i++) data2[i] = data[i];
			return data2;
		} catch (MalformedURLException e) {
			//e.printStackTrace();
			System.out.println("loadClassDataFromURL: "+e);
			return null;
		} catch (IOException e) {
			//e.printStackTrace();
			System.out.println("loadClassDataFromURL: "+e);
			return null;
		}
	}
}