package rrdService.service;
import java.lang.*;
import java.io.*;
import java.util.*;
/**	
* ConfigFile load configuration from a file
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="ConfigFile.java">ConfigFile</a>
*/
public class ConfigFile {	
	/**
	* TAG_SERVER_URL tag which specify the url of the service rrdtool
	*/
	public final String TAG_SERVICE_URL = "SERVICE URL";
	/**
	* TAG_SERVICE_PORT tag which specify the port of the service rrdtool
	*/
	public final String TAG_SERVICE_PORT = "SERVICE PORT";
	/**
	* TAG_MOUNT_DIRECTORY tag which specify the mount directory of the service rrdtool
	*/
	public final String TAG_MOUNT_LIBRARY = "MOUNT LIBRARY";
	/**
	* TAG_CLIENT_URL tag which specify the url of the service client rrdtool
	*/
	public final String TAG_CLIENT_URL = "CLIENT URL";
	/**
	* TAG_CLIENT_PORT tag which specify the port of the service client rrdtool
	*/
	public final String TAG_CLIENT_PORT = "CLIENT PORT";
	/**
	* TAG_TIME_ZONE tag which specify the time zone of reference of rrdtool service
	*/
	public final String TAG_TIME_ZONE = "TIME ZONE";
	/**
	* REM const
	*/
	private final String REM = "REM";
	
	private String serviceURL;
	private String servicePort;
	private String serviceMountLibrary;
	private String serviceTimeZone;
	private String configFile;
	private FileInputStream inputStreamConfigFile;
	private String line;
	private int nbLines = 1;
	private String lexem;
	
	/**
	* Constructor of class ConfigFile
	* @param configFile the file of configuration
	*/
	public ConfigFile(String configFile) throws Exception {
		
		boolean TagServiceUrlDefine = false;
		boolean TagServicePortDefine = false;
		boolean TagMountServiceDefine = false;
		boolean TagServiceTimeZoneDefine = false;
		
		this.configFile = configFile;
		
		File config = new File(configFile);
		if (!config.exists()) throw new Exception(configFile+" doesn\'t exist");
		inputStreamConfigFile = new FileInputStream(config);
		
		while(notEndOfFile()) {
			line = readLine();
			if (isRemLine(line)) {
				skipLine();
			}
			else {
				lexem = readLexem(line);
				if (lexem.equalsIgnoreCase(TAG_SERVICE_URL) && !TagServiceUrlDefine) {
					this.serviceURL = readValue(line);
					TagServiceUrlDefine = true;
				}
				else if (lexem.equalsIgnoreCase(TAG_SERVICE_PORT) && !TagServicePortDefine) {
					this.servicePort = readValue(line);
					TagServicePortDefine = true;
				}
				else if (lexem.equalsIgnoreCase(TAG_MOUNT_LIBRARY) && !TagMountServiceDefine) {
					this.serviceMountLibrary = readValue(line);
					TagMountServiceDefine = true;
				}
				else if (lexem.equalsIgnoreCase(TAG_TIME_ZONE) && !TagServiceTimeZoneDefine) {
					this.serviceTimeZone = readValue(line);
					TagServiceTimeZoneDefine = true;
				}
				else {
					throw new Exception("Error config file "+configFile+" line "+nbLines+": Tag "+lexem+" unknown");
				}
			}
			nbLines++;
		}
		inputStreamConfigFile.close();
		
		// Vrification des paramtres
		if (!TagServiceUrlDefine) throw new Exception("Error config file "+configFile+" line "+nbLines+": Tag Service URL missing");
		if (!TagServicePortDefine) throw new Exception("Error config file "+configFile+" line "+nbLines+": Tag Service Port missing");
		if (!TagServiceTimeZoneDefine) throw new Exception("Error config file "+configFile+" line "+nbLines+": Tag Time zone missing");
		if (!TagMountServiceDefine) throw new Exception("Error config file "+configFile+" line "+nbLines+": Tag Mount Library missing");
	}
	/**
	* notEndOfFile return true if end of config file is reach
	*/
	private boolean notEndOfFile() throws Exception {
		return inputStreamConfigFile.available() > 0;
	}
	/**
	* readLexem read a lexem
	* @param line the line to test
	*/
	private String readLexem(String line) {
		String lexem = new String();
		int i = 0;
		while(i<line.length() && line.charAt(i) != ':') { 
			lexem += line.charAt(i);
			i++;
		}
		return lexem;
	}
	/**
	* skipLine goto the next line
	*/
	private void skipLine() throws Exception {
		while(notEndOfFile() && inputStreamConfigFile.read() != Character.LINE_SEPARATOR);
		while(notEndOfFile() && inputStreamConfigFile.read() == Character.LINE_SEPARATOR);
	}
	/**
	* readLine read a line
	*/
	private String readLine() throws Exception {
		char c;
		String line = new String();
		while(notEndOfFile() && ((c = (char)inputStreamConfigFile.read()) != Character.LINE_SEPARATOR)) {
			line += c;
		}
		if (notEndOfFile()) {
			inputStreamConfigFile.read();
		}
		return line;
	}
	/**
	* isRemLine return true if the is rem
	* @param line the line to test
	*/
	boolean isRemLine(String line) {
		if (line.length() < 3) return false;
		return line.substring(0, REM.length()).equalsIgnoreCase(REM);
	}
	/**
	* readValue read the value of a lexem
	* @param line the line to test
	*/
	private String readValue(String line) throws Exception {
		String value = new String();
		int i = 0;
		while(i<line.length() && line.charAt(i) != ':') i++;
		i++;
		while(i<line.length() && line.charAt(i) != ' ') i++;
		i++;
		while(i<line.length() && line.charAt(i) != ';' && line.charAt(i) != ' ') {
			value+= line.charAt(i);
			i++;
		}
		if (value.equals("")) throw new Exception("Error config file "+configFile+" line "+nbLines+": Value for "+lexem+" missing");
		return value;
	}
	/**
	* getServiceURL() return the Url of the service
	*/
	public String getServiceURL() {
		return serviceURL;
	}
	/**
	* getServicePort() return the port of the service
	*/
	public String getServicePort() {
		return servicePort;
	}
	/**
	* getServiceMountLibrary() return the service Mount Directory of the service
	*/
	public String getServiceMountLibrary() throws Exception {
		return serviceMountLibrary;
	}
	/**
	* Returns the time zone of rrdService 
	*/
	public TimeZone getServiceTimeZone() {
		return TimeZone.getTimeZone(this.serviceTimeZone);
	}
}