package rrdService.service;
import rrdService.util.*;
import java.util.*;
import java.lang.*;
import java.io.*;
/**	
* The class Lock implement a lockItf for writting reading and deleting
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* <dt><b>key-word</b><code>
* <dd>	shared variable
* </code>
* @see <a href="Lock.java">Lock</a>
* @see Mutex
*/
public class Lock implements LockItf {
	/**
	* READ constante
	*/
	public static final int READ = 0;
	/**
	* WRITE constante
	*/
	public static final int WRITE = 1;
	/**
	* DELETE constante
	*/
	public static final int DELETE = 2;
	/**
	* allow to count the number of reading access 
	*/
	private int cptRead;
	/**
	* allow to count the number of writting access 
	*/
	private int cptWrite;
	/**
	* allow to count the number of deleting access 
	*/
	private int cptDelete;
	/**
	* Constructor of class Lock
	*/
	public Lock() {
		cptRead = 0;
		cptWrite = 0;
		cptDelete = 0;
	}	
	/**
	* Lock in reading acces
	* return boolean true if the lock is taken
	*/
	public synchronized boolean lockRead() throws Exception {
		if (cptDelete == 1) {
			return false;
		}
		else if (cptWrite > 0) {
			cptRead++;
			wait();
		}	 
		else {
			cptRead++;
		}
		return true;
	}
	/**
	* Lock in writting acces
	* return boolean true if the lock is taken
	*/
	public synchronized boolean lockWrite() throws Exception  {
		if (cptDelete == 1) {
			return false;
		}
		else if (cptWrite > 0 || cptRead > 0) {
			cptWrite++;
			wait();
		}	 
		else {
			cptWrite++;
		}
		return true;
	}
	/**
	* Lock in deleting acces
	* return boolean true if the lock is taken
	*/
	public synchronized boolean lockDelete() throws Exception  {
		if (cptDelete == 1) {
			return false;
		}
		else if (cptWrite > 0 || cptRead > 0) {
			cptDelete++;
			wait();
		}	 
		else {
			cptDelete++;
		}
		return true;
	}
	/**
	* Unlock in reading acces
	* return boolean true if the lock is left
	*/
	public synchronized boolean unLockRead() throws Exception  {
		cptRead--;
		if (cptRead > 0 || cptWrite > 0 || cptDelete > 0) {
			notify(); 
		}
		return true;
	}
	/**
	* Unlock in writting acces
	* return boolean true if the lock is left
	*/
	public synchronized boolean unLockWrite() throws Exception  {
		cptWrite--;
		if (cptRead > 0 || cptWrite > 0 || cptDelete > 0) {
			notify(); 
		}
		return true;
	}
	/**
	* getStatus return the status of lock
	* return int reprsenting the status READ_WRITE or DELETE
	*/
	public synchronized int getStatus() {
		int result;
		if (cptDelete == 0) result =  READ_WRITE;
		else result = DELETE;
		return result;
	}
	/**
	* toString return a string representation of a lock
	* @return a string representation of a lock
	*/
	public synchronized String toString() {
		String result = new String("[countRead="+cptRead+";countWrite="+cptWrite+";countDelete="+cptDelete+"]");
		return result;
	}
}