package rrdService.service;
import rrdService.util.*;
import java.util.*;
import java.lang.*;
import java.io.*;
/**	
* The class LockTable allows to keep lock of RoundRobin
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* <dt><b>key-word</b><code>
* <dd>	shared variable
* </code>
* @see <a href="src\LockTable.java">LockTable</a>
* @see Lock LockRoundRobinDataBase LockRoundRobinLibrary Mutex
*/
public class LockTable extends Hashtable {
	/**
	* allows the synchonization of the acces to the lockTable
	*/
	private static Mutex mutex;
	/**
	* mountlibrary the mount library
	*/	
	private File mountLibrary;
	/**
	* Constructor of class LockTable
	* @param mountLibrary the mount library
	*/
	public LockTable(File mountLibrary) throws Exception {
		super();
		mutex = new Mutex(1);
		this.mountLibrary = mountLibrary;
		try {
			initLockTable(mountLibrary);
		} catch (Exception e) {
			e.printStackTrace();
			throw new Exception("Enable to init LockTable: "+e.getMessage());
		}
	}
	/**
	* initLockTable scan the mount library and initialiize the lockTable
	* @param directory the mount directory of the mount library
	*/
	private void initLockTable(File directory) throws Exception {
		File[] listFiles = directory.listFiles();
   	    int i=0;
   	    if (listFiles != null ) {
   	    	while(i<listFiles.length) {
   	    		if (listFiles[i].isDirectory()) initLockTable(listFiles[i]);
   	    		else {
   	    			putLock(listFiles[i].getAbsolutePath(), new Lock());
   	    		}
   		   		i++;
   			}
   		}
   	    putLock(directory.getAbsolutePath(), new Lock());
   	}
   	/**
   	* putLock Maps the specified key to the specified value in this hashtable. Neither the key nor the value can be null. 
   	* @param key a string representing the file mount of RoundRobin to put
   	* @param lock the lock of RoundRobin
   	* @return Lock the lock add
   	*/
   	public Lock putLock(String key, Lock lock) {
   		mutex.P();
   		Lock l = (Lock)put(key, lock);
   		mutex.V();
   		return l;
   	}
   	/**
   	* getLock return the Lock withe the scpecific key
   	* @param key a string representing the file mount of RoundRobin to return 
   	* @return Lock the lock associate with the key
   	*/
   	public Lock getLock(String key) throws Exception {
   		mutex.P();
   		Lock lock = (Lock)get(key);
   		if (lock == null) throw new Exception("Lock not found");
   		mutex.V();
   		return lock;
   	}
   	/**
   	* removeLock Removes the key (and its corresponding value) from this LockTable
   	* @param key a string representing the file mount of RoundRobin to remove
   	* @return Lock the lock associate with the key removed
   	*/
   	public Lock removeLock(String key) throws Exception {
   		mutex.P();
   		Lock lock = (Lock)remove(key);
   		if (lock == null) throw new Exception("Lock not found");
   		mutex.V();
   		return lock;
   	}
   	/**
   	* rehashLockTable Increases the capacity of and internally reorganizes this hashtable, in order to accommodate and access its entries more efficiently. This method is called automatically when the number of keys in the hashtable exceeds this hashtable's capacity and load factor. More over re-init the LockTable
   	*/
   	public void rehashLockTable() throws Exception {
   		mutex.P();
   		initLockTable(mountLibrary);
   		rehash();
   		mutex.V();
   	}
   	/**
	* toString return a string representation of a Lock Table
	* @return a string representation of a Lock Table
	*/
	public String toString() {
		mutex.P();
		String result = new String();
		Enumeration values = elements();
		Enumeration keys = keys();
	    while(values.hasMoreElements() && keys.hasMoreElements()) {
    	    result += "key="+keys.nextElement().toString()+";"+values.nextElement().toString()+"\n";
    	}
    	mutex.V();
 		return result;
 	}
}