package rrdService.service;
import rrdService.util.*;
import java.rmi.*;
import java.rmi.server.UnicastRemoteObject;
import java.rmi.registry.*;
import java.net.*;
import java.io.*;
import java.lang.*;
import java.util.*;
/**	
* The class RoundRobinLibrary allows the managment of a group of rrd
* @author Pellier Damien FIRMENICH SA
* @version	1.0
* date : 18/06/01
* </code>
* @see <a href="RoundRobinLibrary.java">RoundRobinLibrary</a>
* @see RoundRobin RoundRobinLibraryItf
*/
public class RoundRobinLibrary extends RoundRobin implements RoundRobinLibraryItf  {	
	/**
	* Constructor of class RoundRobinLibrary
	* @param name the name of the RoundRobinLibrary
	*/
	public RoundRobinLibrary(String name) throws Exception {
		super(name, RRD_LIBRARY);
		if (!this.getMountFile().exists()) {
			try {
				this.setLock(new Lock());
				this.getMountFile().mkdir();
			} catch(Exception e) {
				throwException ("library "+this.getMountFile().getName()+" ", e);
			}
		}
	}
	/**
	* createSubLibrary create a sub library in the current library
	* @param name the name of sub library
	* @return RoundRobinLibraryItf
	*/
	public RoundRobinLibraryItf createSubLibrary(String name) throws RemoteException {
		RoundRobinLibrary library = null;
		RoundRobinLibraryItf newLibrary = null;
		try {
			String newLibraryPath = new String(this.getMountFile().getAbsolutePath()+File.separator+name);
			if (!new File(newLibraryPath).exists()) {
				this.lockWrite();
				library = new RoundRobinLibrary(newLibraryPath);
				this.unLockWrite();
			}
			else {
				library = new RoundRobinLibrary(newLibraryPath);
			}
		} catch(Exception e) {
			//e.printStackTrace();
			throwRemoteException("Error creating subLibrary", e);
		}
		return library;
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param DSContainer a collection of the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				int steps,
				DataSourceContainer DSContainer,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		RoundRobinDataBaseItf roundRobinDataBase = null;
		try {
			String newRoundRobinDataBasePath = new String(this.getMountFile().getAbsolutePath()+File.separator+fileName);
			if (!new File(newRoundRobinDataBasePath).exists()) {
				this.lockWrite();
				roundRobinDataBase = (RoundRobinDataBaseItf)new RoundRobinDataBase(newRoundRobinDataBasePath, startTime, steps,	DSContainer, RRAContainer);
				((RoundRobinDataBase)roundRobinDataBase).getLock().lockWrite();
				this.unLockWrite();
			}
			else {
				roundRobinDataBase = (RoundRobinDataBaseItf)new RoundRobinDataBase(newRoundRobinDataBasePath, startTime, steps,	DSContainer, RRAContainer);
			}
		} catch(Exception e) {
			//e.printStackTrace();
			throwRemoteException("Error creating Round Robin DataBase", e);
		}
		return roundRobinDataBase;
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param dataSource the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	* @return RoundRobinDataBaseItf
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				int steps,
				DataSource dataSource,
				RoundRobinArchive roundRobinArchive) throws RemoteException {
					
		DataSourceContainer DSContainer = new DataSourceContainer();
		DSContainer.addElement(dataSource);
		RoundRobinArchiveContainer RRAContainer = new RoundRobinArchiveContainer();
		RRAContainer.addElement(roundRobinArchive);
		return createRoundRobinDataBase(fileName, startTime, steps, DSContainer, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param dataSource the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				int steps,
				DataSource dataSource,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		DataSourceContainer DSContainer = new DataSourceContainer();
		DSContainer.addElement(dataSource);
		return createRoundRobinDataBase(fileName, startTime, steps, DSContainer, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param DSContainer a collection of the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
			String fileName,
			Time startTime,
			int steps,
			DataSourceContainer DSContainer,
			RoundRobinArchive roundRobinArchive) throws RemoteException {
		
		RoundRobinArchiveContainer RRAContainer = new RoundRobinArchiveContainer();
		RRAContainer.addElement(roundRobinArchive);
		return createRoundRobinDataBase(fileName, startTime, steps, DSContainer, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param DSContainer a collection of the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				int steps,
				DataSourceContainer DSContainer,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
	
		return createRoundRobinDataBase(fileName, null, steps, DSContainer, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param DSContainer a collection of the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				DataSourceContainer DSContainer,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
		
		return createRoundRobinDataBase(fileName, startTime, 0, DSContainer, RRAContainer);			
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param DSContainer a collection of the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				DataSourceContainer DSContainer,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, null, 0, DSContainer, RRAContainer);			
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param dataSource the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	* @return RoundRobinDataBaseItf
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				int steps,
				DataSource dataSource,
				RoundRobinArchive roundRobinArchive) throws RemoteException {

		return createRoundRobinDataBase(fileName, null, steps, dataSource, roundRobinArchive);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param dataSource the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				int steps,
				DataSource dataSource,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, null, steps, dataSource, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param steps Specifies the base interval in seconds with which data will be fed into the RRD (default 0)
	* @param DSContainer a collection of the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
			String fileName,
			int steps,
			DataSourceContainer DSContainer,
			RoundRobinArchive roundRobinArchive) throws RemoteException {
		
		return createRoundRobinDataBase(fileName, null, steps, DSContainer, roundRobinArchive);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param dataSource the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	* @return RoundRobinDataBaseItf
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				DataSource dataSource,
				RoundRobinArchive roundRobinArchive) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, startTime, 0, dataSource, roundRobinArchive);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param dataSource the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				Time startTime,
				DataSource dataSource,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, startTime, 0, dataSource, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param startTime Specifies the time in seconds since 1970-01-01 UTC when the first value should be added to the RRD (default null)
	* @param DSContainer a collection of the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
			String fileName,
			Time startTime,
			DataSourceContainer DSContainer,
			RoundRobinArchive roundRobinArchive) throws RemoteException {
		
		return createRoundRobinDataBase(fileName, startTime, 0, DSContainer, roundRobinArchive);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param dataSource the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	* @return RoundRobinDataBaseItf
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				DataSource dataSource,
				RoundRobinArchive roundRobinArchive) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, null, 0, dataSource, roundRobinArchive);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param dataSource the data source of the RRD
	* @param RRAContainer a collection of the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
				String fileName,
				DataSource dataSource,
				RoundRobinArchiveContainer RRAContainer) throws RemoteException {
					
		return createRoundRobinDataBase(fileName, null, 0, dataSource, RRAContainer);
	}
	/**
	* createRoundRobinDataBase create a round robin database
	* @param fileName the name of the RoundRobinDataBase
	* @param DSContainer a collection of the data source of the RRD
	* @param roundRobinArchive the RRA of the RRD
	*/
	public RoundRobinDataBaseItf createRoundRobinDataBase(
			String fileName,
			DataSourceContainer DSContainer,
			RoundRobinArchive roundRobinArchive) throws RemoteException {
		
		return createRoundRobinDataBase(fileName, null, 0, DSContainer, roundRobinArchive);
	}
	/**
	* delete delete a rrd
	* @return int the number of rrd deleted
	*/
	public int delete() throws RemoteException {
		int rrd = 0;
		try {			
			this.lockDelete();
			rrd = delete(this.getMountFile());
		} catch (Exception e) {
			throwRemoteException("Error deleting library "+this.getName(), e);
		}
		return rrd;
	}
	/**
	* delete delete a rrd
	* @param lib the RoundRobinLibrary to start deleting
	* @return int the number of rrd deleted
	*/
	private int delete(File directory) throws Exception {
		int rrd = 0;
		File[] listFiles = directory.listFiles();
		for (int i=0;i<listFiles.length; i++) {
			if (listFiles[i].isDirectory()) {
				rrd += delete(listFiles[i]);
			}
   	    	else {
   	    		listFiles[i].delete();
   	    		RoundRobinService.lockTable.removeLock(listFiles[i].getAbsolutePath());
   	    		rrd ++;
   	    	}
		}
		directory.delete();
		RoundRobinService.lockTable.removeLock(directory.getAbsolutePath());
		rrd ++;
		return rrd;	
	}
	/**
	* ListRoundRobin returns an RoundRobinContainer
	* @return RoundRobinContainer
	*/
	public RoundRobinContainer listRoundRobin() throws RemoteException {
		RoundRobinContainer container = new RoundRobinContainer();
		try {			
			this.lockRead();
			File[] listFiles = this.getMountFile().listFiles();
			for (int i=0; i<listFiles.length; i++) {
				if (listFiles[i].isDirectory() && this.getLock().getStatus() == READ_WRITE)
					container.addElement(new RoundRobinLibrary(listFiles[i].getAbsolutePath()));
				else if (listFiles[i].isFile() && isRoundRobinDataBase(listFiles[i])&& this.getLock().getStatus() == READ_WRITE) 
					container.addElement(new RoundRobinDataBase(listFiles[i].getAbsolutePath()));
				else {}
			}
			this.unLockRead();
		} catch (Exception e) {
			throwRemoteException("Error listing RoundRobins in library "+this.getName(), e);
		}
		return container;
	}
	/**
	* ListLibrary returns RoundRobinLibraryContainer
	* @return RoundRobinLibraryContainer
	*/
	public RoundRobinLibraryContainer listRoundRobinLibrary() throws RemoteException {
		RoundRobinLibraryContainer container = new RoundRobinLibraryContainer();
		try {			
			this.lockRead();
			File[] listFiles = this.getMountFile().listFiles();
			for (int i=0; i<listFiles.length; i++) {
				if (listFiles[i].isDirectory() && this.getLock().getStatus() == READ_WRITE) 
					container.addElement(new RoundRobinLibrary(listFiles[i].getAbsolutePath()));
			}
			this.unLockRead();
		} catch (Exception e) {
			throwRemoteException("Error listing RoundRobinLibraries in library "+this.getName(), e);
		}
		return container;
	}
	/**
	* ListRoundRobinDataBase returns RoundRobinDataBaseContainer
	* @return RoundRobinDataBaseContainer
	*/
	public RoundRobinDataBaseContainer listRoundRobinDataBase() throws RemoteException {
		RoundRobinDataBaseContainer container = new RoundRobinDataBaseContainer();
		try {
			this.lockRead();
			File[] listFiles = this.getMountFile().listFiles();
			for (int i=0; i<listFiles.length; i++) {
				if (listFiles[i].isFile() && isRoundRobinDataBase(listFiles[i]) && this.getLock().getStatus() == READ_WRITE) 
					container.addElement(new RoundRobinDataBase(listFiles[i].getAbsolutePath()));
			}
			this.unLockRead();
		} catch(Exception e) {
			throwRemoteException("Error listing RoundRobinDataBases in library "+this.getName(), e);
		}
		return container;
	}
	/**
	* Returns RoundRobinLibraryItf according to its name null otherwise
	* @param libraryname the name of the library to find
	* @return RoundRobinLibraryItf
	*/
	public RoundRobinLibraryItf findLibrary(String libraryName) throws RemoteException {
		RoundRobinLibraryItf library = null;
		try {			
			File[] listFiles = this.getMountFile().listFiles();
			for (int i=0; i<listFiles.length; i++) {
				if (listFiles[i].isDirectory() &&
						 this.getLock().getStatus() == READ_WRITE &&
						 listFiles[i].getName().equals(libraryName)) {
					 library = (RoundRobinLibraryItf)new RoundRobinLibrary(listFiles[i].getAbsolutePath());
					 break;
				}
			}
		} catch (Exception e) {
			throwRemoteException("Error finding RoundRobinLibrary "+libraryName, e);
		}
		return library;
	}
	/**
	* Returns RoundRobindataBaseItf according to its name null otherwise
	* @param RRDName the name of the round robin data base to find
	* @return RoundRobinDataBaseItf
	*/
	public RoundRobinDataBaseItf findRRD(String RRDName) throws RemoteException {
		RoundRobinDataBaseItf rrd = null;
		try {		
			File[] listFiles = this.getMountFile().listFiles();			
			//System.out.println(listFiles.length);
			for (int i=0; i<listFiles.length; i++) {
				//System.out.println(listFiles[i].getName()+" |"+RRDName+"|");
				if (listFiles[i].getName().equals(RRDName) &&
						 this.getLock().getStatus() == READ_WRITE) {
					rrd = (RoundRobinDataBaseItf)new RoundRobinDataBase(listFiles[i].getAbsolutePath());
					break;
				}
			}
		} catch (Exception e) {
			throwRemoteException("Error finding RoundRobinDataBase "+RRDName, e);
		}
		return rrd;
	}
	/**
	* getSize return the size in bytes of RRD
	* @return long
	*/
	public long getSize() throws RemoteException {
		long RoundRobinLibrarySize = 0;
		try {	
			this.lockRead();
			RoundRobinLibrarySize = getRoundRobinLibrarySize(this.getMountFile());
			this.unLockRead();
		} catch (Exception e) {
			throwRemoteException("Error getting size of library "+this.getName(), e);
		}
		return RoundRobinLibrarySize;
   	}
   	/**
	* getRoundRobinLibrarySize return the size in bytes of RRD
	* @param directory the directory to start
	* @return long
	*/
   	private long getRoundRobinLibrarySize(File directory) throws Exception {
   		long RRDSize = 0;
		File[] listFiles;
   	    listFiles = directory.listFiles();
   	    int i=0;
   	    while(i<listFiles.length) {
   	    	if (listFiles[i].isDirectory()) RRDSize += getRoundRobinLibrarySize(listFiles[i]);
   	    	else {
   	    		RRDSize += listFiles[i].length();
   	    	}
   		   	i++;
   		}
   	    return RRDSize;
   	}
   	/**
	* Lock in reading acces
	* return boolean true if the lock is taken
	*/
	public boolean lockRead() throws Exception {
		boolean result = false;
		try{
		//	System.out.println("result = lock(new File("+this.getAbsolutePath()+"), READ);");
			result = lock(new File(this.getAbsolutePath()), Lock.READ);
		} catch (Exception e) {

			throwException("Error locking in Read", e);
		}
		return result;
	}	
	/**
	* Lock in writting acces
	* return boolean true if the lock is taken
	*/
	public boolean lockWrite() throws Exception {
		boolean result = false;
		try{
		//	System.out.println("result = lock(new File("+this.getAbsolutePath()+"), WRITE);");
			result = lock(new File(this.getAbsolutePath()), Lock.WRITE);
		} catch (Exception e) {
			e.printStackTrace();
			throwException("Error locking in Write", e);
		}
		return result;
	}
	/**
	* Lock in deleting acces
	* return boolean true if the lock is taken
	*/
	public boolean lockDelete() throws Exception {
		boolean result = false;
		try {
			//System.out.println("result = lock(new File("+this.getAbsolutePath()+"), DELETE);");
			result = lock(new File(this.getAbsolutePath()), Lock.DELETE);
		} catch (Exception e) {
			throwException("Error locking in Delete", e);
		}
		return result;
	}
	/**
	* Unlock in reading acces
	* return boolean true if the lock is left
	*/
	public boolean unLockRead() throws Exception {
		boolean result = false;
		try{
			//System.out.println("result = unLock(new File("+this.getAbsolutePath()+"), READ);");
			result = unLock(new File(this.getAbsolutePath()), Lock.READ);
		} catch (Exception e) {
			throwException("Error unlocking in Read", e);
		}
		return result;
	}	
	/**
	* Unlock in writting acces
	* return boolean true if the lock is left
	*/
	public boolean unLockWrite()  throws Exception {
		boolean result = false;
		try{
			//System.out.println("result = unLock(new File("+this.getAbsolutePath()+"), WRITE);");
			result = unLock(new File(this.getAbsolutePath()), Lock.WRITE);
		} catch (Exception e) {
			throwException("Error unlocking in Write", e);
		}
		return result;
	}	
	/**
	* Unlock in delete acces
	* return boolean true if the lock is left
	*/
	public boolean unLockDelete() throws Exception {
		boolean result = false;
		try{
			//System.out.println("result = unLock(new File("+this.getAbsolutePath()+"), DELETE);");
			result = unLock(new File(this.getAbsolutePath()), Lock.DELETE);
		} catch (Exception e) {
			throwException("Error unlocking in Delete", e);
		}
		return result;
	}	
	/**
	* Lock a library acces
	* return boolean true if the lock is taken
	*/	
	private boolean lock(File directory, int mode) throws Exception {
		boolean result = true;
		//System.out.println("Avant le lock de "+directory.getAbsolutePath());
		//System.out.println(RoundRobinService.lockTable.toString());
		if (mode == Lock.READ) {
			if (!super.lockRead()) return false;
		}
		else if (mode == Lock.WRITE) {
			if (!super.lockWrite()) return false;
		}
		else if (mode == Lock.DELETE) {
			if (!super.lockDelete()) return false;
		}
		else {
			throw new Exception("Error Lock mode not match");
		}
		// Lock de son contenu
		File[] listFiles = directory.listFiles(new RoundRobinFilter());
   	    if (listFiles != null) {
   	    	int i=0;
   	    	while(i<listFiles.length) {
	   	    	if (listFiles[i].isDirectory() && RoundRobinService.lockTable.getLock(this.getAbsolutePath()).getStatus() == READ_WRITE) {
	   	    		RoundRobinLibrary library = new RoundRobinLibrary(listFiles[i].getAbsolutePath());
	   	    		try {
						if (mode == Lock.READ) 
							result = result && library.lockRead();
						else if (mode == Lock.WRITE) 
							result = result && library.lockWrite();
						else // if (mode == DELETE) {
							result = result && library.lockDelete();
					} catch (Exception e) {
						throw new Exception("Enable to lock the library "+listFiles[i].getName()+": "+e.getMessage());
					}
				}
				else  {
					try {
						RoundRobinDataBase rrdFile = new RoundRobinDataBase(listFiles[i].getAbsolutePath());
						if (mode == Lock.READ) 
							result = result && rrdFile.lockRead();
						else if (mode == Lock.WRITE) 
							result = result && rrdFile.lockWrite();
						else // if (mode == DELETE) {
							result = result && rrdFile.lockDelete();
					} catch (Exception e) {
						throw new Exception("Enable to lock the RoundRobinDataBase "+listFiles[i].getName()+": "+e.getMessage());
					}
				}
	   		   	i++;
	   		}
	   	}
   		//System.out.println("Apres le lock de "+directory.getAbsolutePath());
		//System.out.println(RoundRobinService.lockTable.toString());
   		return result;
   	}
   	/**
	* unLock a library access
	* return boolean true if the unlock is well done
	*/	
	private boolean unLock(File directory, int mode) throws Exception {
		boolean result = true;
		//System.out.println("Avant le unlock de "+directory.getAbsolutePath());
		//System.out.println(RoundRobinService.lockTable.toString());
		// Lock de son contenu
		File[] listFiles = directory.listFiles(new RoundRobinFilter());
   	    if (listFiles != null) {
   	    	int i=0;
   	    	while(i<listFiles.length) {
	   	    	if (listFiles[i].isDirectory() && RoundRobinService.lockTable.getLock(this.getAbsolutePath()).getStatus() == READ_WRITE) {
	   	    		RoundRobinLibrary library = new RoundRobinLibrary(listFiles[i].getAbsolutePath());
	   	    		try {
						if (mode == Lock.READ) {
							result = result && unLock(listFiles[i], Lock.READ);
						}
						else if (mode == Lock.WRITE) {
							result = result && unLock(listFiles[i], Lock.WRITE);
						}
						else {
							throw new Exception("Error Lock mode not match");
						}
					} catch (Exception e) {
						throw new Exception("Enable to unlock the library "+listFiles[i].getName()+": "+e.getMessage());
					}
				}
				else  {
					try {
						RoundRobinDataBase rrdFile = new RoundRobinDataBase(listFiles[i].getAbsolutePath());
						if (mode == Lock.READ) {
							result = result && rrdFile.unLockRead();
						}
						else if (mode == Lock.WRITE) {
							result = result && rrdFile.unLockWrite();
						}
						else {
							throw new Exception("Error Lock mode not match");
						}
					} catch (Exception e) {
						throw new Exception("Enable to unlock the RoundRobinDataBase "+listFiles[i].getName()+": "+e.getMessage());
					}
				}
	   		   	i++;
	   		}
	   	}
	   	if (mode == Lock.READ) {
	   		RoundRobinService.lockTable.getLock(directory.getAbsolutePath()).unLockRead();
		}
		else {
			RoundRobinService.lockTable.getLock(directory.getAbsolutePath()).unLockWrite();
		}
		//System.out.println("Apres le unlock de "+directory.getAbsolutePath());
		//System.out.println(RoundRobinService.lockTable.toString());		
   		return result;
   	}
}