
package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
import java.awt.Color;
/**	
* The class AeraGraphicObject Does the same as LINE?, but the area between 0 and the graph will be filled with the color specified. 
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="AeraGraphicObject.java">AeraGraphicObject</a>
* @see RoundRobinGraphic 
*/
public class AeraGraphicObject extends GraphicObject implements Serializable {
	/**
	* virtualName the virtual name to print on graphic
	*/
	protected String virtualName;
	/**
	* Constructor of AeraGraphicObject
	* @param virtualName the virtual name to print on graphic
	*/
	public AeraGraphicObject(String virtualName) {
		setVirtualName(virtualName);
		this.color = null;
		this.legend = null;
	}
	/**
	* Constructor of AeraGraphicObject
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	*/
	public AeraGraphicObject(String virtualName,
						Color color) {
		setVirtualName(virtualName);
		setColor(color);
		this.legend = null;
	}
	/**
	* Constructor of AeraGraphicObject
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	* @param legend the legend of the text on graphic
	*/
	public AeraGraphicObject(String virtualName,
						Color color,
						String legend) {
		setVirtualName(virtualName);
		setColor(color);
		setLegend(legend);
	}
	/**
	* Replaces the virtual name to print on graphic
	* @param virtualName the virtual name to print on graphic
	*/
	public void setVirtualName(String virtualName) {
		this.virtualName = virtualName;
	}
	/**
	* Returns the virtual name to print on graphic
	*/
	public String getVirtualName() {
		return this.virtualName;
	}
	/**
	* Returns a string representation of this AeraGraphicObject
	*/
	public String toString(){
		String result = new String();
		result = "AERA:";
		RoundRobinColor c = new RoundRobinColor(virtualName, color);
		if (color != null) {
			result += ":"+c.toString();
		}
		else {
			result += ":"+virtualName;
		}
		if (legend != null) 
			result += ":"+legend;
		return result;
	}
}