package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class CdpPrepContainer allows to stock a list of CdpPrep
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="CdpPrepContainer.java">CdpPrepContainer</a>
* @see Vector
*/
public class CdpPrepContainer extends Vector {
	/**
	* Constructs an empty CdpPrepContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public CdpPrepContainer() {
		super();
	}
    /**
    * Constructs a CdpPrepContainer containing the CdpPrep of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose CdpPreps are to be placed into this CdpPrepContainer.
    */
    public CdpPrepContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty CdpPrepContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the CdpPrepContainer.
    */
    public CdpPrepContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty CdpPrepContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the CdpPrepContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the CdpPrepContainer overflows
    */
    public CdpPrepContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this CdpPrepContainer.
    * return CdpPrepContainer
    */
    public CdpPrepContainer cloneCdpPrepContainer() {
    	return (CdpPrepContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this CdpPrepContainer.
    * @return CdpPrep
    */
 	public CdpPrep cdpPrepAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (CdpPrep)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this CdpPrepContainer. 
    * @return CdpPrep
    */ 
    public CdpPrep firstCdpPrep() throws NoSuchElementException {
    	return (CdpPrep)firstElement();
    }
    /**
    * Returns the CdpPrep at the specified position in this CdpPrepContainer.
    * @param index index of CdpPrep to return.
    * @return CdpPrep
    */
 	public CdpPrep getCdpPrep(int index) throws ArrayIndexOutOfBoundsException {
 		return (CdpPrep)get(index);
 	}
    /**
    * Returns the last component of the CdpPrepContainer. 
    * @return CdpPrep
    */      
 	public CdpPrep lastCdpPrep() throws NoSuchElementException {
 		return (CdpPrep)lastElement();
 	}
    /**
    * Removes the CdpPrep at the specified position in this CdpPrepContainer. 
    * @param index index of CdpPrep to remove
    * @return CdpPrep
    */      
 	public CdpPrep removeCdpPrep(int index) throws ArrayIndexOutOfBoundsException {
 		return (CdpPrep)remove(index);
 	}
    /**
    * Replaces the CdpPrep at the specified position in this CdpPrepContainer with the specified CdpPrep. 
    * @param index index of CdpPrep to replace.
	* @param lib RoundRobinDataBase to be stored at the specified position.
    * @return CdpPrep
    */
    public CdpPrep setCdpPrep(int index, CdpPrep cdpPrep) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (CdpPrep)set(index, cdpPrep);
    }
 	/**
    * Returns an array containing all of the CdpPrep in this CdpPrepContainer in the correct order. 
    * @return CdpPrep
    */      
 	public CdpPrep[] toCdpPrepArray() {
 		return (CdpPrep[])toArray();
 	}
 	/**
 	* Returns an array containing all of the CdpPrep in this CdpPrepContainer in the correct order. 
 	* @param a the array into which the CdpPrep of the CdpPrepContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return CdpPrep
 	*/
 	public CdpPrep[] toCdpPrepArray(CdpPrep[] a) throws ArrayStoreException {
 		return (CdpPrep[])toArray(a);
 	}
}