package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class Data representing the data used for updating the RRD was acquired at a certain time.
* This time can either be defined in seconds since 1970-01-01. Or by using the letter 'N' the 
* update time is set to be the current time. Negative time values are subtracted from the 
* current time. Getting the timing right to the second is especially important when you are 
* working with data-sources of type COUNTER, DERIVE or ABSOLUTE.
* The remaining elements of the argument are DS updates. The order of this list is the same
* as the order the data sources were defined in the rra. If there is no data for a certain 
* data-source, the letter U can be defined.
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* <dt><b>key-word</b><code>
* <dd>  RoundRobin
* </code>
* @see <a href="Data.java">Data</a>
* @see RoundRobinDataBase
*/
public class Data implements Serializable {
	/**
	* timestamp of this data
	*/
	private String timestamp;
	/**
	* value of this data
	*/
	private String value;
	/**
	* Default constructor of class Data with timestam rigth now and value unknown
	*/
	public Data() throws Exception {
		setTimestamp("N");
		setValue("U");
	}
	/**
	* Constructor of class Data with timestamp rigth now and a specific value
	* @param value the value of this Data
	*/
	public Data(double value) throws Exception {
		setTimestamp("N");
		setValue(String.valueOf(value));
	}
	/**
	* Constructor of class Data with a specific timestamp and a unknown value
	* @param timestamp the timstamp of this Data
	*/
	public Data(Time timestamp) throws Exception {
		setTimestamp(timestamp.toString());
		setValue("U");
	}
	/**
	* Constructor of class Data with specific timestam and value
	* @param timestamp the timstamp of this Data
	* @param value the value of this Data
	*/
	public Data(Time timestamp, double value) throws Exception {
		setTimestamp(timestamp.toString());
		setValue(String.valueOf(value));
	}
	/**
	* setTimestamp replace timstamp of this Data
	* @param timestamp the timstamp to set
	*/
	public void setTimestamp(String timestamp) {
		this.timestamp = timestamp;
	}
	/**
	* setValue replace value of this Data
	* @param value the value to set
	*/
	public void setValue(String value) {
		this.value = value;
	}
	/**
	* getTimestamp return the timstamp of this Data
	*/
	public String getTimestamp() {
		return this.timestamp;
	}
	/**
	* getValue return the value of this Data
	*/
	public String getValue() {
		return this.value;
	}
	/**
	* toString return a string representation of this data
	*/
	public String toString() {
		return timestamp+":"+value;
	}
}