package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
import java.awt.Color;
/**	
* The class LineGraphicObject
* Plot for the requested data, using the color specified. Write a legend
* into the graph. The 3 possible keywords <STRONG>
* <FONT SIZE="-1">LINE1</FONT></STRONG>, <STRONG>
* <FONT SIZE="-1">LINE2</FONT></STRONG>, and <STRONG>
* <FONT SIZE="-1">LINE3</FONT></STRONG>
* generate increasingly wide lines. If no color is defined,
* the drawing is done 'blind' this is useful in connection with the
* <STRONG>
* <FONT SIZE="-1">STACK</FONT></STRONG> function when you want to
* <FONT SIZE="-1">ADD</FONT> the values of two
* data-sources without showing it in the graph.
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="LineGraphicObject.java">LineGraphicObject</a>
* @see RoundRobinGraphic Comment
*/
public class LineGraphicObject extends AeraGraphicObject {
	/**
	* lineNumber the number of line of this line graphic object
	*/
	protected int lineNumber;
	/**
	* Constructor of LineGraphicObject
	* @param lineNumber the number of line of this line graphic object
	* @param virtualName the virtual name to print on graphic
	*/
	public LineGraphicObject(int lineNumber,
						String virtualName) throws Exception {
		super(virtualName);
		setLineNumber(lineNumber);
	}
	/**
	* Constructor of LineGraphicObject
	* @param lineNumber the number of line of this line graphic object
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	*/
	public LineGraphicObject(int lineNumber,
						String virtualName,
						Color color) throws Exception {
		super(virtualName, color);
		setLineNumber(lineNumber);
	}
	/**
	* Constructor of LineGraphicObject
	* @param lineNumber the number of line of this line graphic object
	* @param virtualName the virtual name to print on graphic
	* @param color the color of the text on graphic
	* @param legend the legend of the text on graphic
	*/
	public LineGraphicObject(int lineNumber,
						String virtualName,
						Color color,
						String legend) throws Exception {
		super(virtualName, color, legend);
		setLineNumber(lineNumber);
	}
	/**
	* Replaces the number of line of this line graphic object
	* @param lineNumber the number of line of this line graphic object
	*/
	public void setLineNumber(int lineNumber) throws Exception {
		if (1 < lineNumber || lineNumber > 3) throw new Exception("The number of line must be in [1..3]");
		this.lineNumber = lineNumber;
	}
	/**
	* Returns the number of line of this line graphic object
	*/
	public int getLineNumber() {
		return this.lineNumber;
	}
	/**
	* Returns a string representation of this line graphic object
	*/
	public String toString(){
		String result = new String();
		result = "LINE"+String.valueOf(lineNumber);
		if (color != null) {
			RoundRobinColor c = new RoundRobinColor(virtualName, color);
			result += ":"+c.toString();
		}
		else {
			result += ":"+virtualName;
		}
		if (legend != null) 
			result += ":"+legend;
		return result;
	}
}