package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class RoundRobinArchiveContainer allows to stock a list of RoundRobinArchive
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinArchiveContainer.java">RoundRobinArchiveContainer</a>
* @see Vector RoundRobinArchive
*/
public class RoundRobinArchiveContainer extends Vector {
	/**
	* Constructs an empty RoundRobinArchiveContainerso that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public RoundRobinArchiveContainer() {
		super();
	}
    /**
    * Constructs a RoundRobinArchiveContainercontaining the RoundRobinArchive of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose RoundRobinArchives are to be placed into this RoundRobinArchiveContainer.
    */
    public RoundRobinArchiveContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty RoundRobinArchiveContainerwith the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the RoundRobinArchiveContainer.
    */
    public RoundRobinArchiveContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty RoundRobinArchiveContainerwith the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the RoundRobinArchiveContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the RoundRobinArchiveContaineroverflows
    */
    public RoundRobinArchiveContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this RoundRobinArchiveContainer.
    * return RoundRobinArchiveContainer
    */
    public RoundRobinArchiveContainer cloneRoundRobinArchiveContainer() {
    	return (RoundRobinArchiveContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this RoundRobinArchiveContainer.
    * @return RoundRobinArchive
    */
 	public RoundRobinArchive roundRobinArchiveAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinArchive)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this RoundRobinArchiveContainer. 
    * @return RoundRobinArchive
    */ 
    public RoundRobinArchive firstRoundRobinArchive() throws NoSuchElementException {
    	return (RoundRobinArchive)firstElement();
    }
    /**
    * Returns the RoundRobinArchive at the specified position in this RoundRobinArchiveContainer.
    * @param index index of RoundRobinArchive to return.
    * @return RoundRobinArchive
    */
 	public RoundRobinArchive getRoundRobinArchive(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinArchive)get(index);
 	}
    /**
    * Returns the last component of the RoundRobinArchiveContainer. 
    * @return RoundRobinArchive
    */      
 	public RoundRobinArchive lastRoundRobinArchive() throws NoSuchElementException {
 		return (RoundRobinArchive)lastElement();
 	}
    /**
    * Removes the RoundRobinArchive at the specified position in this RoundRobinArchiveContainer. 
    * @param index index of RoundRobinArchive to remove
    * @return RoundRobinArchive
    */      
 	public RoundRobinArchive removeRoundRobinArchive(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinArchive)remove(index);
 	}
    /**
    * Replaces the RoundRobinArchive at the specified position in this RoundRobinArchiveContainerwith the specified RoundRobinArchive. 
    * @param index index of RoundRobinArchive to replace.
	* @param rra RoundRobinArchive to be stored at the specified position.
    * @return RoundRobinArchive
    */
    public RoundRobinArchive setRoundRobinArchive(int index, RoundRobinArchive rra) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (RoundRobinArchive)set(index, rra);
    }
 	/**
    * Returns an array containing all of the RoundRobinArchive in this RoundRobinArchiveContainerin the correct order. 
    * @return RoundRobinArchive
    */      
 	public RoundRobinArchive[] toRoundRobinArchiveArray() {
 		return (RoundRobinArchive[])toArray();
 	}
 	/**
 	* Returns an array containing all of the RoundRobinArchive in this RoundRobinArchiveContainerin the correct order. 
 	* @param a the array into which the RoundRobinArchive of the RoundRobinArchiveContainerare to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return RoundRobinArchive
 	*/
 	public RoundRobinArchive[] toRoundRobinArchiveArray(RoundRobinArchive[] a) throws ArrayStoreException {
 		return (RoundRobinArchive[])toArray(a);
 	}
 	/**
 	* toString return a string representation of this RoundRobinArchiveContainer
 	*/
 	public String toString() {
 		String result = new String();
 		for (int i=0; i<size(); i++) {
 			result += 	"rra["+String.valueOf(i)+"].cf = "+roundRobinArchiveAt(i).getConsolidationFunction()+"\n"+
 						"rra["+String.valueOf(i)+"].row = "+String.valueOf(roundRobinArchiveAt(i).getRows())+"\n"+
 						"rra["+String.valueOf(i)+"].pdp_per_row = "+String.valueOf(roundRobinArchiveAt(i).getSteps())+"\n"+
 						"rra["+String.valueOf(i)+"].xff = "+String.valueOf(roundRobinArchiveAt(i).getXFilesFactor())+"\n";
 						CdpPrepContainer container = roundRobinArchiveAt(i).getCdpPrepContainer();
 			for (int j=0; j<container.size(); j++) {
 				Double value = container.cdpPrepAt(j).getValue();
 				if (value == null) {
 					result += "rra["+String.valueOf(i)+"].cdp_prep["+String.valueOf(j)+"].value = NaN\n";
 				}
 				else { 
 					result += "rra["+String.valueOf(i)+"].cdp_prep["+String.valueOf(j)+"].value = "+String.valueOf(value.longValue())+"\n";
 				}
 				result += "rra["+String.valueOf(i)+"].cdp_prep["+String.valueOf(j)+"].unknown_datapoints = "+String.valueOf(container.cdpPrepAt(j).getUnknownDataPoints())+"\n";
 			}
 		}
 		return result;
 	}
}