package rrdService.util;
import rrdService.service.*;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class RoundRobinDataBaseContainer allows to transmits a Container of RoundRobinDataBase to client
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinDataBaseContainer.java">RoundRobinDataBaseContainer</a>
* @see Vector RoundRobinDataBase
*/
public class RoundRobinDataBaseContainer extends Vector {
	/**
	* Constructs an empty RoundRobinDataBaseContainer so that its internal data array has size 10 and its standard capacity increment is zero. 
	*/
	public RoundRobinDataBaseContainer() {
		super();
	}
    /**
    * Constructs a RoundRobinDataBaseContainer containing the RoundRobinDataBaseItf of the specified collection, in the order they are returned by the collection's iterator. 
    * @param c the collection whose RoundRobinDataBaseItfs are to be placed into this RoundRobinDataBaseContainer.
    */
    public RoundRobinDataBaseContainer(Collection c) {
		super(c);
	}
    /**
    * Constructs an empty RoundRobinDataBaseContainer with the specified initial capacity and with its capacity increment equal to zero. 
    * param initialCapacity the initial capacity of the RoundRobinDataBaseContainer.
    */
    public RoundRobinDataBaseContainer(int initialCapacity) throws IllegalArgumentException {
		super(initialCapacity);
	}
	/**
    * Constructs an empty RoundRobinDataBaseContainer with the specified initial capacity and capacity increment.
    * @param initialCapacity the initial capacity of the RoundRobinDataBaseContainer.
    * @param capacityIncrement the amount by which the capacity is increased when the RoundRobinDataBaseContainer overflows
    */
    public RoundRobinDataBaseContainer(int initialCapacity, int capacityIncrement) throws IllegalArgumentException {
		super(initialCapacity, capacityIncrement);
	}
	/**
    * Returns a clone of this RoundRobinDataBaseContainer.
    * return RoundRobinDataBaseContainer
    */
    public RoundRobinDataBaseContainer cloneRoundRobinDataBaseContainer() {
    	return (RoundRobinDataBaseContainer)clone();
   	}
    /**
    * Returns the component at the specified index. 
    * @param index an index into this RoundRobinDataBaseContainer.
    * @return RoundRobinDataBaseItf
    */
 	public RoundRobinDataBaseItf roundRobinDataBaseAt(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinDataBaseItf)elementAt(index);
 	}
    /**
    * Returns the first component (the item at index 0) of this RoundRobinDataBaseContainer. 
    * @return RoundRobinDataBaseItf
    */ 
    public RoundRobinDataBaseItf firstRoundRobinDataBase() throws NoSuchElementException {
    	return (RoundRobinDataBaseItf)firstElement();
    }
    /**
    * Returns the RoundRobinDataBaseItf at the specified position in this RoundRobinDataBaseContainer.
    * @param index index of RoundRobinDataBaseItf to return.
    * @return RoundRobinDataBaseItf
    */
 	public RoundRobinDataBaseItf getRoundRobinDataBase(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinDataBaseItf)get(index);
 	}
    /**
    * Returns the last component of the RoundRobinDataBaseContainer. 
    * @return RoundRobinDataBaseItf
    */      
 	public RoundRobinDataBaseItf lastRoundRobinDataBase() throws NoSuchElementException {
 		return (RoundRobinDataBaseItf)lastElement();
 	}
    /**
    * Removes the RoundRobinDataBaseItf at the specified position in this RoundRobinDataBaseContainer. 
    * @param index index of RoundRobinDataBaseItf to remove
    * @return RoundRobinDataBaseItf
    */      
 	public RoundRobinDataBaseItf removeRoundRobinDataBase(int index) throws ArrayIndexOutOfBoundsException {
 		return (RoundRobinDataBaseItf)remove(index);
 	}
    /**
    * Replaces the RoundRobinDataBaseItf at the specified position in this RoundRobinDataBaseContainer with the specified RoundRobinDataBaseItf. 
    * @param index index of RoundRobinDataBaseItf to replace.
	* @param rrd RoundRobinDataBase to be stored at the specified position.
    * @return RoundRobinDataBaseItf
    */
    public RoundRobinDataBaseItf setRoundRobinDataBase(int index, RoundRobinDataBaseItf rrd) throws ArrayIndexOutOfBoundsException, IllegalArgumentException {
    	return (RoundRobinDataBaseItf)set(index, rrd);
    }
 	/**
    * Returns an array containing all of the RoundRobinDataBaseItf in this RoundRobinDataBaseContainer in the correct order. 
    * @return RoundRobinDataBaseItf
    */      
 	public RoundRobinDataBaseItf[] toRoundRobinDataBaseArray() {
 		return (RoundRobinDataBaseItf[])toArray();
 	}
 	/**
 	* Returns an array containing all of the RoundRobinDataBaseItf in this RoundRobinDataBaseContainer in the correct order. 
 	* @param a the array into which the RoundRobinDataBaseItf of the RoundRobinDataBaseContainer are to be stored, if it is big enough; otherwise, a new array of the same runtime type is allocated for this purpose.
    * @return RoundRobinDataBaseItf
 	*/
 	public RoundRobinDataBaseItf[] toRoundRobinDataBaseArray(RoundRobinDataBaseItf[] a) throws ArrayStoreException {
 		return (RoundRobinDataBaseItf[])toArray(a);
 	}
}