package rrdService.util;
import java.util.*;
import java.io.*;
import java.lang.*;
/**	
* The class RoundRobinImage allows to transmits a image to the client
* @author	Damien Pellier
* @version	1.0
* date : 15/07/2001
* </code>
* @see <a href="RoundRobinImage.java">RoundRobinImage</a>
*/
public class RoundRobinImage implements Serializable {
	/**
	* Name of this image
	*/
	private String imageName;
	/**
	* The image under a string representation
	*/
	private byte[] image;
	/**
	* Constructor of a RoundRobinImage
	* @paran imageNames the file which represent this image
	*/
	public RoundRobinImage(File imageFile) throws Exception {
		this.imageName = imageFile.getName();
		FileInputStream fileInputStream = new FileInputStream(imageFile);
   		image = new byte[fileInputStream.available()];
   		fileInputStream.read(image);
   		fileInputStream.close();
   	}
   	/**
 	* Serialize this image into the specific directory
 	* @param directory the directory where serialize this image
 	*/
 	public void serialize(File directory) throws Exception {
		File serializableFile = new File(directory, imageName);
 		if (serializableFile.exists()) {
 			serializableFile.delete();
 		}
 		serializableFile.createNewFile();
 		FileOutputStream  fileOutputStream = new FileOutputStream(serializableFile);
 		fileOutputStream.write(image);
 		fileOutputStream.close();
 	}
 	/**
 	* Returns the name of this image
 	*/
 	public String getName() {
 		return this.imageName;
 	}
}